==> cxf-testutils-2.0.3.1-fuse-sources.jar: org/apache/type_test/types3/StructWithOccuringChoice.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithOccuringChoice complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithOccuringChoice">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInteger" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;choice maxOccurs="unbounded" minOccurs="0">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithOccuringChoice", propOrder = {
    "varInteger",
    "varIntOrVarString"
})
public class StructWithOccuringChoice {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected int varInteger;
    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types3", required = true, type = String.class)
    })
    protected List<Serializable> varIntOrVarString;

    /**
     * Gets the value of the varInteger property.
     * 
     */
    public int getVarInteger() {
        return varInteger;
    }

    /**
     * Sets the value of the varInteger property.
     * 
     */
    public void setVarInteger(int value) {
        this.varInteger = value;
    }

    /**
     * Gets the value of the varIntOrVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntOrVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntOrVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarIntOrVarString() {
        if (varIntOrVarString == null) {
            varIntOrVarString = new ArrayList<Serializable>();
        }
        return this.varIntOrVarString;
    }

}

==> cxf-testutils-2.0.6.3-fuse-sources.jar: org/apache/type_test/types3/StructWithOccuringChoice.java <==

package org.apache.type_test.types3;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithOccuringChoice complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithOccuringChoice">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInteger" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;choice maxOccurs="unbounded" minOccurs="0">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithOccuringChoice", propOrder = {
    "varInteger",
    "varIntOrVarString"
})
public class StructWithOccuringChoice {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected int varInteger;
    @XmlElements({
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types3", required = true, type = String.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class)
    })
    protected List<Serializable> varIntOrVarString;

    /**
     * Gets the value of the varInteger property.
     * 
     */
    public int getVarInteger() {
        return varInteger;
    }

    /**
     * Sets the value of the varInteger property.
     * 
     */
    public void setVarInteger(int value) {
        this.varInteger = value;
    }

    /**
     * Gets the value of the varIntOrVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntOrVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntOrVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getVarIntOrVarString() {
        if (varIntOrVarString == null) {
            varIntOrVarString = new ArrayList<Serializable>();
        }
        return this.varIntOrVarString;
    }

}
